@@ -41,28 +41,33 @@ BANNER = """
    "P'        ""         ""
 """
 
-REMOTE_COPY = "scp -o User=root -q"
-REMOTE_EXEC = "ssh -o User=root -q"
+REMOTE_COPY = "scp -o User=root"
+REMOTE_EXEC = "ssh -o User=root"
+
 
 class Error(Exception):
     """Base exception class for this project"""
     pass
 
+
 class UnresolvableRequirementsError(cdist.Error):
     """Resolving requirements failed"""
     pass
 
+
 class CdistObjectError(Error):
     """Something went wrong with an object"""
-    
+
     def __init__(self, cdist_object, message):
         self.name = cdist_object.name
         self.source = " ".join(cdist_object.source)
         self.message = message
 
-
     def __str__(self):
-        return '%s: %s (defined at %s)' % (self.name, self.message, self.source)
+        return '%s: %s (defined at %s)' % (self.name,
+                                           self.message,
+                                           self.source)
+
 
 def file_to_list(filename):
     """Return list from \n seperated file"""
