@@ -26,6 +26,7 @@ import shutil
 import sys
 import time
 import pprint
+import itertools
 
 import cdist
 
@@ -34,25 +35,47 @@ import cdist.exec.remote
 
 from cdist import core
 
+
 class Config(object):
     """Cdist main class to hold arbitrary data"""
 
     def __init__(self, local, remote, dry_run=False):
 
-        self.local      = local
-        self.remote     = remote
-        self.log        = logging.getLogger(self.local.target_host)
-        self.dry_run    = dry_run
+        self.local = local
+        self.remote = remote
+        self.log = logging.getLogger(self.local.target_host)
+        self.dry_run = dry_run
 
-        self.explorer = core.Explorer(self.local.target_host, self.local, self.remote)
+        self.explorer = core.Explorer(self.local.target_host, self.local,
+                                      self.remote)
         self.manifest = core.Manifest(self.local.target_host, self.local)
-        self.code     = core.Code(self.local.target_host, self.local, self.remote)
+        self.code = core.Code(self.local.target_host, self.local, self.remote)
 
     def _init_files_dirs(self):
         """Prepare files and directories for the run"""
         self.local.create_files_dirs()
         self.remote.create_files_dirs()
 
+    @staticmethod
+    def hosts(source):
+        """Yield hosts from source.
+           Source can be a sequence or filename (stdin if \'-\').
+           In case of filename each line represents one host.
+        """
+        if isinstance(source, str):
+            import fileinput
+            try:
+                for host in fileinput.input(files=(source)):
+                    # remove leading and trailing whitespace
+                    yield host.strip()
+            except (IOError, OSError) as e:
+                raise cdist.Error("Error reading hosts from \'{}\'".format(
+                    source))
+        else:
+            if source:
+                for host in source:
+                    yield host
+
     @classmethod
     def commandline(cls, args):
         """Configure remote system"""
@@ -60,60 +83,73 @@ class Config(object):
 
         # FIXME: Refactor relict - remove later
         log = logging.getLogger("cdist")
-    
+
+        if args.manifest == '-' and args.hostfile == '-':
+            raise cdist.Error(("Cannot read both, manifest and host file, "
+                               "from stdin"))
+        # if no host source is specified then read hosts from stdin
+        if not (args.hostfile or args.host):
+            args.hostfile = '-'
+
         initial_manifest_tempfile = None
         if args.manifest == '-':
             # read initial manifest from stdin
             import tempfile
             try:
-                handle, initial_manifest_temp_path = tempfile.mkstemp(prefix='cdist.stdin.')
+                handle, initial_manifest_temp_path = tempfile.mkstemp(
+                        prefix='cdist.stdin.')
                 with os.fdopen(handle, 'w') as fd:
                     fd.write(sys.stdin.read())
             except (IOError, OSError) as e:
-                raise cdist.Error("Creating tempfile for stdin data failed: %s" % e)
-    
+                raise cdist.Error(("Creating tempfile for stdin data "
+                                   "failed: %s" % e))
+
             args.manifest = initial_manifest_temp_path
             import atexit
             atexit.register(lambda: os.remove(initial_manifest_temp_path))
-    
+
         process = {}
         failed_hosts = []
         time_start = time.time()
-    
-        for host in args.host:
+
+        hostcnt = 0
+        for host in itertools.chain(cls.hosts(args.host),
+                                    cls.hosts(args.hostfile)):
+            hostcnt += 1
             if args.parallel:
                 log.debug("Creating child process for %s", host)
-                process[host] = multiprocessing.Process(target=cls.onehost, args=(host, args, True))
+                process[host] = multiprocessing.Process(
+                        target=cls.onehost, args=(host, args, True))
                 process[host].start()
             else:
                 try:
                     cls.onehost(host, args, parallel=False)
                 except cdist.Error as e:
                     failed_hosts.append(host)
-    
+
         # Catch errors in parallel mode when joining
         if args.parallel:
             for host in process.keys():
                 log.debug("Joining process %s", host)
                 process[host].join()
-    
+
                 if not process[host].exitcode == 0:
                     failed_hosts.append(host)
-    
+
         time_end = time.time()
-        log.info("Total processing time for %s host(s): %s", len(args.host),
-                    (time_end - time_start))
-    
+        log.info("Total processing time for %s host(s): %s", hostcnt,
+                 (time_end - time_start))
+
         if len(failed_hosts) > 0:
-            raise cdist.Error("Failed to configure the following hosts: " + 
-                " ".join(failed_hosts))
-    
+            raise cdist.Error("Failed to configure the following hosts: " +
+                              " ".join(failed_hosts))
+
     @classmethod
     def onehost(cls, host, args, parallel):
         """Configure ONE system"""
 
         log = logging.getLogger(host)
-    
+
         try:
             local = cdist.exec.local.Local(
                 target_host=host,
@@ -125,10 +161,10 @@ class Config(object):
                 target_host=host,
                 remote_exec=args.remote_exec,
                 remote_copy=args.remote_copy)
-    
+
             c = cls(local, remote, dry_run=args.dry_run)
             c.run()
-    
+
         except cdist.Error as e:
             log.error(e)
             if parallel:
@@ -136,7 +172,7 @@ class Config(object):
                 sys.exit(1)
             else:
                 raise
-    
+
         except KeyboardInterrupt:
             # Ignore in parallel mode, we are existing anyway
             if parallel:
@@ -156,49 +192,50 @@ class Config(object):
         self.iterate_until_finished()
 
         self.local.save_cache()
-        self.log.info("Finished successful run in %s seconds", time.time() - start_time)
-
+        self.log.info("Finished successful run in %s seconds",
+                      time.time() - start_time)
 
     def object_list(self):
         """Short name for object list retrieval"""
-        for cdist_object in core.CdistObject.list_objects(self.local.object_path,
-                                                         self.local.type_path,
-                                                         self.local.object_marker_name):
+        for cdist_object in core.CdistObject.list_objects(
+                self.local.object_path, self.local.type_path,
+                self.local.object_marker_name):
             if cdist_object.cdist_type.is_install:
-                self.log.debug("Running in config mode, ignoring install object: {0}".format(cdist_object))
+                self.log.debug(("Running in config mode, ignoring install "
+                                "object: {0}").format(cdist_object))
             else:
                 yield cdist_object
 
-
     def iterate_once(self):
         """
-            Iterate over the objects once - helper method for 
+            Iterate over the objects once - helper method for
             iterate_until_finished
         """
-        objects_changed  = False
+        objects_changed = False
 
         for cdist_object in self.object_list():
             if cdist_object.requirements_unfinished(cdist_object.requirements):
                 """We cannot do anything for this poor object"""
                 continue
-        
+
             if cdist_object.state == core.CdistObject.STATE_UNDEF:
                 """Prepare the virgin object"""
-        
+
                 self.object_prepare(cdist_object)
                 objects_changed = True
-        
+
             if cdist_object.requirements_unfinished(cdist_object.autorequire):
-                """The previous step created objects we depend on - wait for them"""
+                """The previous step created objects we depend on -
+                   wait for them
+                """
                 continue
-        
+
             if cdist_object.state == core.CdistObject.STATE_PREPARED:
                 self.object_run(cdist_object)
                 objects_changed = True
 
         return objects_changed
 
-
     def iterate_until_finished(self):
         """
             Go through all objects and solve them
@@ -224,22 +261,32 @@ class Config(object):
                 requirement_names = []
                 autorequire_names = []
 
-                for requirement in cdist_object.requirements_unfinished(cdist_object.requirements):
+                for requirement in cdist_object.requirements_unfinished(
+                        cdist_object.requirements):
                     requirement_names.append(requirement.name)
 
-                for requirement in cdist_object.requirements_unfinished(cdist_object.autorequire):
+                for requirement in cdist_object.requirements_unfinished(
+                        cdist_object.autorequire):
                     autorequire_names.append(requirement.name)
 
                 requirements = "\n        ".join(requirement_names)
-                autorequire  = "\n        ".join(autorequire_names)
-                info_string.append("%s requires:\n        %s\n%s autorequires:\n        %s" % (cdist_object.name, requirements, cdist_object.name, autorequire))
+                autorequire = "\n        ".join(autorequire_names)
+                info_string.append(("%s requires:\n"
+                                    "        %s\n"
+                                    "%s ""autorequires:\n"
+                                    "        %s" % (
+                                        cdist_object.name,
+                                        requirements, cdist_object.name,
+                                        autorequire)))
 
-            raise cdist.UnresolvableRequirementsError("The requirements of the following objects could not be resolved:\n%s" %
-                ("\n".join(info_string)))
+            raise cdist.UnresolvableRequirementsError(
+                    ("The requirements of the following objects could not be "
+                     "resolved:\n%s") % ("\n".join(info_string)))
 
     def object_prepare(self, cdist_object):
         """Prepare object: Run type explorer + manifest"""
-        self.log.info("Running manifest and explorers for " + cdist_object.name)
+        self.log.info(
+                "Running manifest and explorers for " + cdist_object.name)
         self.explorer.run_type_explorers(cdist_object)
         self.manifest.run_type_manifest(cdist_object)
         cdist_object.state = core.CdistObject.STATE_PREPARED
@@ -249,7 +296,8 @@ class Config(object):
 
         self.log.debug("Trying to run object %s" % (cdist_object.name))
         if cdist_object.state == core.CdistObject.STATE_DONE:
-            raise cdist.Error("Attempting to run an already finished object: %s", cdist_object)
+            raise cdist.Error(("Attempting to run an already finished "
+                               "object: %s"), cdist_object)
 
         cdist_type = cdist_object.cdist_type
 
@@ -272,7 +320,6 @@ class Config(object):
         else:
             self.log.info("Skipping code execution due to DRY RUN")
 
-
         # Mark this object as done
         self.log.debug("Finishing run of " + cdist_object.name)
         cdist_object.state = core.CdistObject.STATE_DONE
