@@ -36,15 +36,16 @@ my_dir = op.abspath(op.dirname(__file__))
 fixtures = op.join(my_dir, 'fixtures')
 conf_dir = op.join(fixtures, 'conf')
 
+
 class CodeTestCase(test.CdistTestCase):
 
     def setUp(self):
         self.local_dir = self.mkdtemp()
 
         self.local = local.Local(
-            target_host=self.target_host, 
-            base_path = self.local_dir,
-            exec_path = cdist.test.cdist_exec_path,
+            target_host=self.target_host,
+            base_path=self.local_dir,
+            exec_path=cdist.test.cdist_exec_path,
             add_conf_dirs=[conf_dir])
         self.local.create_files_dirs()
 
@@ -52,16 +53,19 @@ class CodeTestCase(test.CdistTestCase):
         remote_exec = self.remote_exec
         remote_copy = self.remote_copy
         self.remote = remote.Remote(
-            target_host=self.target_host, 
-            remote_exec=remote_exec, 
+            target_host=self.target_host,
+            remote_exec=remote_exec,
             remote_copy=remote_copy,
             base_path=self.remote_dir)
         self.remote.create_files_dirs()
 
         self.code = code.Code(self.target_host, self.local, self.remote)
 
-        self.cdist_type = core.CdistType(self.local.type_path, '__dump_environment')
-        self.cdist_object = core.CdistObject(self.cdist_type, self.local.object_path, 'whatever', self.local.object_marker_name)
+        self.cdist_type = core.CdistType(self.local.type_path,
+                                         '__dump_environment')
+        self.cdist_object = core.CdistObject(
+                self.cdist_type, self.local.object_path, 'whatever',
+                self.local.object_marker_name)
         self.cdist_object.create()
 
     def tearDown(self):
@@ -73,42 +77,56 @@ class CodeTestCase(test.CdistTestCase):
         output_dict = {}
         for line in output_string.split('\n'):
             if line:
-                junk,value = line.split(': ')
+                junk, value = line.split(': ')
                 key = junk.split(' ')[1]
                 output_dict[key] = value
         self.assertEqual(output_dict['__target_host'], self.local.target_host)
         self.assertEqual(output_dict['__global'], self.local.base_path)
         self.assertEqual(output_dict['__type'], self.cdist_type.absolute_path)
-        self.assertEqual(output_dict['__object'], self.cdist_object.absolute_path)
-        self.assertEqual(output_dict['__object_id'], self.cdist_object.object_id)
+        self.assertEqual(output_dict['__object'],
+                         self.cdist_object.absolute_path)
+        self.assertEqual(output_dict['__object_id'],
+                         self.cdist_object.object_id)
         self.assertEqual(output_dict['__object_name'], self.cdist_object.name)
+        self.assertEqual(output_dict['__files'], self.local.files_path)
 
     def test_run_gencode_remote_environment(self):
         output_string = self.code.run_gencode_remote(self.cdist_object)
         output_dict = {}
         for line in output_string.split('\n'):
             if line:
-                junk,value = line.split(': ')
+                junk, value = line.split(': ')
                 key = junk.split(' ')[1]
                 output_dict[key] = value
         self.assertEqual(output_dict['__target_host'], self.local.target_host)
         self.assertEqual(output_dict['__global'], self.local.base_path)
         self.assertEqual(output_dict['__type'], self.cdist_type.absolute_path)
-        self.assertEqual(output_dict['__object'], self.cdist_object.absolute_path)
-        self.assertEqual(output_dict['__object_id'], self.cdist_object.object_id)
+        self.assertEqual(output_dict['__object'],
+                         self.cdist_object.absolute_path)
+        self.assertEqual(output_dict['__object_id'],
+                         self.cdist_object.object_id)
         self.assertEqual(output_dict['__object_name'], self.cdist_object.name)
+        self.assertEqual(output_dict['__files'], self.local.files_path)
 
     def test_transfer_code_remote(self):
-        self.cdist_object.code_remote = self.code.run_gencode_remote(self.cdist_object)
+        self.cdist_object.code_remote = self.code.run_gencode_remote(
+                self.cdist_object)
         self.code.transfer_code_remote(self.cdist_object)
-        destination = os.path.join(self.remote.object_path, self.cdist_object.code_remote_path)
+        destination = os.path.join(self.remote.object_path,
+                                   self.cdist_object.code_remote_path)
         self.assertTrue(os.path.isfile(destination))
 
     def test_run_code_local(self):
-        self.cdist_object.code_local = self.code.run_gencode_local(self.cdist_object)
+        self.cdist_object.code_local = self.code.run_gencode_local(
+                self.cdist_object)
         self.code.run_code_local(self.cdist_object)
 
     def test_run_code_remote_environment(self):
-        self.cdist_object.code_remote = self.code.run_gencode_remote(self.cdist_object)
+        self.cdist_object.code_remote = self.code.run_gencode_remote(
+                self.cdist_object)
         self.code.transfer_code_remote(self.cdist_object)
         self.code.run_code_remote(self.cdist_object)
+
+if __name__ == '__main__':
+    import unittest
+    unittest.main()
